#######################
PyDMWaveformPlot
#######################

.. autoclass:: pydm.widgets.waveformplot.PyDMWaveformPlot
   :members:
   :show-inheritance:

#######################
WaveformCurveItem
#######################

.. autoclass:: pydm.widgets.waveformplot.WaveformCurveItem
   :members:
   :show-inheritance:
